@@ -237,7 +237,7 @@ class TestModel(models.Model):
         self.message_post(_('Variables not translatable: %s, %s' % (
             variable1, variable2)))
         self.message_post(body=_('Variable not translatable: %s' % variable1))
-        self.message_post(body=_('Variables not translatable: %s' % (
+        self.message_post(body=_('Variables not translatable: %s %s' % (
             variable1, variable2)))
         error_msg = _('Variable not translatable: %s' % variable1)
         error_msg = _('Variables not translatable: %s, %s' % (
@@ -245,6 +245,17 @@ class TestModel(models.Model):
         error_msg = _('Variable not translatable: {}'.format(variable1))
         error_msg = _('Variables not translatable: {}, {variable2}'.format(
             variable1, variable2=variable2))
+
+        # string with parameters without name
+        # so you can't change the order in the translation
+        _('%s %d') % ('hello', 3)
+        _('%s %s') % ('hello', 'world')
+
+        # Valid cases
+        _('%(strname)s') % {'strname': 'hello'}
+        _('%(strname)s %(intname)d') % {'strname': 'hello', 'intname': 3}
+        _('%s') % 'hello'
+        _('%d') % 3
         return error_msg
 
     def my_method2(self, variable2):
